@@ -13,6 +13,7 @@ PN_SUBSCRIBE_KEY = "sub-c-6fb03d68-6a78-11e2-ae8f-12313f022c90"
 PN_CHANNEL = "PlatformChannel"
 
 _LOGGER = logging.getLogger(__name__)
+OUTPUT_FILE = ".pubnub.log"
 
 
 class VivintPubNubSubscribeListener(SubscribeCallback):
@@ -51,6 +52,8 @@ class VivintPubNubSubscribeListener(SubscribeCallback):
         message: PNMessageResult,
     ) -> None:
         """Handle a message received."""
+        with open(OUTPUT_FILE, "a", encoding="utf-8") as f:
+            f.write(f"{message.timetoken}: {message.message}\n")
         self.__message_received_callback(message.message)
 
 
